@@ -3,7 +3,7 @@
 /*                  This file is part of the class library                   */
 /*       SoPlex --- the Sequential object-oriented simPlex.                  */
 /*                                                                           */
-/*  Copyright 1996-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 1996-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -60,13 +60,13 @@ public:
    }
 
    template < class S >
-   Nonzero<R>(const Nonzero<S>& vec)
+   Nonzero(const Nonzero<S>& vec)
       : val(vec.val)
       , idx(vec.idx)
    {
    }
 
-   Nonzero<R>()
+   Nonzero()
       : val()
       , idx(0)
    {
@@ -163,14 +163,14 @@ public:
    /// Number of used indices.
    int size() const
    {
-      assert(m_elem != 0 || memused == 0);
+      assert(m_elem != nullptr || memused == 0);
       return memused;
    }
 
    /// Maximal number of indices.
    int max() const
    {
-      assert(m_elem != 0 || memused == 0);
+      assert(m_elem != nullptr || memused == 0);
       return memsize;
    }
 
@@ -196,7 +196,7 @@ public:
     */
    int pos(int i) const
    {
-      if(m_elem != 0)
+      if(m_elem != nullptr)
       {
          int n = size();
 
@@ -281,7 +281,7 @@ public:
    /// Append one nonzero \p (i,v).
    void add(int i, const R& v)
    {
-      assert(m_elem != 0);
+      assert(m_elem != nullptr);
       assert(size() < max());
 
       if(v != 0.0)
@@ -299,7 +299,7 @@ public:
    /// Append one uninitialized nonzero.
    void add(int i)
    {
-      assert(m_elem != 0);
+      assert(m_elem != nullptr);
       assert(size() < max());
 
       int n = size();
@@ -448,7 +448,7 @@ public:
    /// Sort nonzeros to increasing indices.
    void sort()
    {
-      if(m_elem != 0)
+      if(m_elem != nullptr)
       {
          Nonzero<R> dummy;
          Nonzero<R>* w;
@@ -622,12 +622,12 @@ public:
     *  beginning of the memory block. Once this memory has been passed, it shall not be modified until the SVectorBase
     *  is no longer used.
     */
-   explicit SVectorBase<R>(int n = 0, Nonzero<R>* p_mem = 0)
+   explicit SVectorBase(int n = 0, Nonzero<R>* p_mem = nullptr)
    {
       setMem(n, p_mem);
    }
 
-   SVectorBase<R>(const SVectorBase<R>& sv) = default;
+   SVectorBase(const SVectorBase<R>& sv) = default;
 
    /// Assignment operator.
    template < class S >
@@ -647,7 +647,7 @@ public:
 
          while(i--)
          {
-            assert(e != 0);
+            assert(e != nullptr);
 
             if(s->val != 0.0)
             {
@@ -692,7 +692,7 @@ public:
 
          while(i--)
          {
-            assert(e != 0);
+            assert(e != nullptr);
 
             if(s->val != 0.0)
             {
@@ -798,14 +798,14 @@ public:
    /// Set size of the vector.
    void set_size(int s)
    {
-      assert(m_elem != 0 || s == 0);
+      assert(m_elem != nullptr || s == 0);
       memused = s;
    }
 
    /// Set the maximum number of nonzeros in the vector.
    void set_max(int m)
    {
-      assert(m_elem != 0 || m == 0);
+      assert(m_elem != nullptr || m == 0);
       memsize = m;
    }
 
@@ -813,7 +813,7 @@ public:
    void setMem(int n, Nonzero<R>* elmem)
    {
       assert(n >= 0);
-      assert(n == 0 || elmem != 0);
+      assert(n == 0 || elmem != nullptr);
 
       m_elem = elmem;
       set_size(0);
@@ -831,13 +831,13 @@ public:
    {
 #ifdef ENABLE_CONSISTENCY_CHECKS
 
-      if(m_elem != 0)
+      if(m_elem != nullptr)
       {
          const int my_size = size();
          const int my_max = max();
 
          if(my_size < 0 || my_max < 0 || my_size > my_max)
-            return MSGinconsistent("SVectorBase");
+            return SPX_MSG_INCONSISTENT("SVectorBase");
 
          for(int i = 1; i < my_size; ++i)
          {
@@ -845,7 +845,7 @@ public:
             {
                // allow trailing zeros
                if(m_elem[i].idx == m_elem[j].idx && m_elem[i].val != 0)
-                  return MSGinconsistent("SVectorBase");
+                  return SPX_MSG_INCONSISTENT("SVectorBase");
             }
          }
       }
@@ -855,6 +855,44 @@ public:
       return true;
    }
 
+   /// Checks whether the array contains any nan entries.
+   bool hasNaNs() const
+   {
+      if(!std::is_floating_point<R>::value)
+      {
+         return false;
+      }
+
+      for(int i = 0; i < size(); ++i)
+      {
+         if(isnan(m_elem[i].val))
+         {
+            return true;
+         }
+      }
+
+      return false;
+   }
+
+   /// Checks whether the array contains any NaN entries.
+   bool hasInfs() const
+   {
+      if(!std::is_floating_point<R>::value)
+      {
+         return false;
+      }
+
+      for(int i = 0; i < size(); ++i)
+      {
+         if(isinf(m_elem[i].val))
+         {
+            return true;
+         }
+      }
+
+      return false;
+   }
+
    ///@}
 };
 
